<?php

namespace App\Http\Controllers\Admin;

use App\Http\Controllers\Controller;
use Illuminate\Http\Request;
use App\Models\Campaign;
use App\Models\User;
use App\Models\Brand;

class DashboardController extends Controller
{
    // public function users()
    // {
    //     $users = User::all();
    //     return view('Admin.users.index', compact('users'));
    // }
    public function users(Request $request)
    {
        // Search query from the request
        $search = $request->input('search');

        // Fetch users with search and paginate
        $users = User::when($search, function ($query, $search) {
            return $query->where('first_name', 'LIKE', "%{$search}%")
                        ->orWhere('last_name', 'LIKE', "%{$search}%")
                        ->orWhere('email', 'LIKE', "%{$search}%");
        })->paginate(10);

        return view('Admin.users.index', compact('users', 'search'));
    }

    public function viewUser($id)
    {
        $users = User::find($id);
        return view('Admin.users.view', compact('users'));
    }

    public function addCampaign(Request $request)
    {
         return view('Admin.campaigns.add');
    }

    public function campaigns(Request $request)
{
    // Get the search query from the request
    $search = $request->input('search');

    // Fetch campaigns with optional search and pagination
    $campaigns = Campaign::when($search, function ($query, $search) {
        $query->where('name', 'LIKE', "%{$search}%");
    })
    ->paginate(10); // Change the number as needed for pagination

    return view('Admin.campaigns.index', compact('campaigns', 'search'));
}

    public function deleteCampaigns($id)
    {
        $campaign = Campaign::find($id);
        $campaign->delete();
        return redirect('/campaigns')->with('status', "Campaign deleted Successfully");
    }

    public function editCampaigns($id)
    {
        $campaign = Campaign::find($id);
        return view('Admin.campaigns.edit', compact('campaign'));

    }

    public function updateCampaigns(Request $request, $id)
    {
        $request->validate([
            'name' => 'required|string|max:255',
        ]);

        // Find the category
        $category = Campaign::findOrFail($id);
        // Update the category
        $category->update([
            'name' => $request->input('name'),
        ]);

        return redirect('/campaigns')->with('status', 'Campaign updated successfully!');
    }

    public function brands(Request $request)
    {
        // Get the search query from the request
        $search = $request->input('search');

        // Fetch brands with optional search and pagination
        $brands = Brand::when($search, function ($query, $search) {
            return $query->where('name', 'LIKE', "%{$search}%");
        })->paginate(10);

        return view('Admin.brands.index', compact('brands', 'search'));
    }


    public function deleteBrands($id)
    {
        $brands = Brand::find($id);
        $brands->delete();
        return redirect('/brands')->with('status', "Brand deleted Successfully");
    }

    public function editBrands($id)
    {
        $Brands = Brand::find($id);
        return view('Admin.brands.edit', compact('Brands'));

    }

    public function updateBrands(Request $request, $id)
    {
        $request->validate([
            'name' => 'required|string|max:255',
        ]);

        // Find the category
        $Brand = Brand::findOrFail($id);
        // Update the category
        $Brand->update([
            'name' => $request->input('name'),
        ]);

        return redirect('/brands')->with('status', 'Brand updated successfully!');
    }

    public function storeCampaign(Request $request)
    {
        $request->validate([
            'name' => 'required|string|max:255',
        ]);


        // Create the category
        Campaign::create([
            'name' => $request->name,
        ]);

        return redirect('/campaigns')->with('status', "Campaigns Added Successfully");
    }

    public function addBrand(Request $request)
    {
        return view('Admin.brands.add');
    }

    public function storeBrand(Request $request)
    {
        $request->validate([
            'name' => 'required|string|max:255',
        ]);

        // Create the category
        Brand::create([
            'name' => $request->name,
        ]);

        return redirect('/brands')->with('status', "Brand Added Successfully");
    }
}
