<?php

namespace App\Http\Controllers\Admin;

use App\Http\Controllers\Controller;
use Illuminate\Http\Request;
use App\Models\Order;

class OrderController extends Controller
{
    public function index(Request $request)
    {
        $query = Order::query();

        // Search by User Name
        if ($request->filled('search')) {
            $query->whereHas('user', function ($q) use ($request) {
                $q->where('first_name', 'like', '%' . $request->search . '%')
                    ->orWhere('last_name', 'like', '%' . $request->search . '%');
            });
        }

        // Filter by Status
        if ($request->filled('status')) {
            $query->where('status', $request->status);
        }

        $orders = $query->paginate(10);

        return view('Admin.orders.index', compact('orders'));
    }
    
    
    public function view($id)
    {


        $order = Order::with('carts', 'user')->where('id', $id)->first();
        return view('Admin.orders.view', compact('order'));
    }

    public function updateOrder(Request $request, $id)
    {
        $order = Order::find($id);
        $order->status = $request->input('order_status');
        $order->update();
        return redirect('orders')->with('status', 'Order Status Updated Successfully');
    }
    public function orderHistory()
    {
        $order = Order::where('status', '1')->get();
        return view('Admin.orders.completedOrders', compact('order'));
    }
    
       public function updateStatus(Request $request, Order $order)
    {
        $request->validate([
            'status' => 'required|in:processing,completed,cancelled',
        ]);

        $order->status = $request->status;
        $order->save();

        return response()->json(['success' => true]);
    }
}
