<?php

namespace App\Http\Controllers;

use App\Models\CampaignContext;
use App\Models\Brand;
use App\Models\Category;
use App\Models\Campaign;
use Illuminate\Http\Request;

class CampaignContextController extends Controller
{ 

    public function homeIndex(Request $request)
    {
        // Get the search query from the request
        $search = $request->input('search');

        // Fetch campaign contexts with optional search and pagination
        $campaignContexts = CampaignContext::with('brand', 'category', 'campaign')
        ->where('is_global', 1)
        ->when($search, function ($query, $search) {
            $query->whereHas('campaign', function ($q) use ($search) {
                $q->where('name', 'LIKE', "%{$search}%");
            });
        })
        ->paginate(10);

        return view('Admin.home-context.index', compact('campaignContexts', 'search'));
    }
    
    public function index(Request $request)
    {
        // Get the search query from the request
        $search = $request->input('search');

        // Fetch campaign contexts with optional search and pagination
        $campaignContexts = CampaignContext::with(['brand', 'category'])
            ->where('is_global', 0)
            ->when($search, function ($query, $search) {
                $query->whereHas('brand', function ($q) use ($search) {
                    $q->where('name', 'LIKE', "%{$search}%");
                })
                ->orWhereHas('category', function ($q) use ($search) {
                    $q->where('name', 'LIKE', "%{$search}%");
                });
            })
            ->paginate(10);

        return view('Admin.campaign-context.index', compact('campaignContexts', 'search'));
    }


    public function create()
    {
        $brands = Brand::all();
        $categories = Category::all();
        $campaigns = Campaign::all();
        return view('Admin.campaign-context.create', compact('brands', 'categories','campaigns'));
    }

    public function homeCreate()
    {
        $brands = Brand::all();
        $categories = Category::all();
        $campaigns = Campaign::all();
        return view('Admin.home-context.create', compact('brands', 'categories','campaigns'));
    }

    public function store(Request $request)
    {
        $data = $request->validate([
            'brand_id' => 'required',
            'category_id' => 'required',
            'campaign_id' => 'required',
        ]);
    
    
        CampaignContext::create($data);
    
        return redirect('/campaign-context')->with('status', "Campaign Assigned to category  Successfully");
    }

    
    public function HomeCampaignStore(Request $request)
    {
        $data = $request->validate([
            'campaign_id' => 'required',
            'is_global'=>'required',
        ]);

        CampaignContext::create($data);
        return redirect('/home-campaign-context')->with('status', "Campaign Assigned to Home Screen  Successfully");
    }


    public function edit($id)
    {
        $campaignContext = CampaignContext::findOrFail($id);
        $brands = Brand::all();
        $categories = Category::all();
        $campaigns = Campaign::all();
        return view('Admin.campaign-context.edit', compact('campaignContext', 'brands', 'categories','campaigns'));
    }

    
    public function homeEdit($id)
    {
        $campaignContext = CampaignContext::findOrFail($id);
        $brands = Brand::all();
        $categories = Category::all();
        $campaigns = Campaign::all();
        return view('Admin.home-context.edit', compact('campaignContext', 'brands', 'categories','campaigns'));
    }
    

    
    public function homeUpdate(Request $request, $id)
    {
        $campaignContext = CampaignContext::findOrFail($id);
        
        $data = $request->validate([
            'campaign_id' => 'required'
        ]);

        $campaignContext->update($data);
    
        return redirect('/home-campaign-context')->with('status', 'Home Campaign  updated successfully');
    }

    public function update(Request $request, $id)
    {
        $campaignContext = CampaignContext::findOrFail($id);
        
        $data = $request->validate([
            'brand_id' => 'required',
            'category_id' => 'required',
            'campaign_id' => 'required'
        ]);

        $campaignContext->update($data);
    
        return redirect()->route('campaign-context.index')->with('status', 'Category Campaign  updated successfully');
    }
    public function destroy($id)
    {
        $campaignContext = CampaignContext::findOrFail($id);
        $campaignContext->delete();
        return redirect('/home-campaign-context')->with('status', "Campaign Removed  from category  Successfully");
    }
}

